@@ -26,4 +26,8 @@ def test_simple_bar():
     bar.add('test2', map(abs, rng))
     bar.x_labels = map(str, rng)
     bar.title = "Bar test"
-    bar._in_browser()
+    q = bar.render_pyquery()
+    assert len(q(".axis.x")) == 1
+    assert len(q(".axis.y")) == 1
+    assert len(q(".legend")) == 2
+    assert len(q(".plot .series rect")) == 2 * 3
